##  Dashboard Structure
The Application Portfolio Management dashboard consists of the following elements:
  * Live applications by business capability
  * application run cost broken down by business capability
  * Portfolio Complexity
  * Data Quality KPI
